@@ -228,7 +228,9 @@ class FireSmokeUseCase(BaseProcessor):
             # Step 10: Events and tracking stats
             events = self._generate_events(fire_smoke_summary, alerts, config, frame_number=frame_number)
             tracking_stats = self._generate_tracking_stats(
-                fire_smoke_summary, insights, summary_text, config, frame_number=frame_number
+                fire_smoke_summary, insights, summary_text, config,
+                frame_number=frame_number,
+                stream_info=stream_info
             )
 
             # Finalize context and return result
